package com.ruoyi.flowable.listener;

import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.TemplateMessageEnum;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.flowable.flow.FindNextNodeUtil;
import com.ruoyi.flowable.service.IFlowBusinessKeyService;
import com.ruoyi.system.domain.SysUserOpenid;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.system.mapper.SysUserOpenidMapper;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateData;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateMessage;
import org.apache.commons.collections4.CollectionUtils;
import org.flowable.bpmn.model.UserTask;
import org.flowable.common.engine.api.delegate.event.FlowableEngineEntityEvent;
import org.flowable.engine.RepositoryService;
import org.flowable.engine.RuntimeService;
import org.flowable.engine.TaskService;
import org.flowable.engine.delegate.event.AbstractFlowableEngineEventListener;
import org.flowable.engine.runtime.ProcessInstance;
import org.flowable.identitylink.api.IdentityLink;
import org.flowable.task.api.Task;
import org.flowable.task.service.impl.persistence.entity.TaskEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * Flowable全局监听器
 *
 * @author JiangYuQi
 */
@Slf4j
@Component
public class GlobalEventListener extends AbstractFlowableEngineEventListener {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private TaskService taskService;

    @Autowired
    private WxMpService wxMpService;

    @Autowired
    private SysDeptMapper sysDeptMapper;

    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private RuntimeService runtimeService;

    @Autowired
    private RepositoryService repositoryService;

    @Autowired
    private SysUserOpenidMapper sysUserOpenidMapper;

    @Autowired
    private IFlowBusinessKeyService flowBusinessKeyService;

    @Override
    protected void processCompleted(FlowableEngineEntityEvent event) {
        log.info("任务流程审批完成...{}",event.getProcessInstanceId());
        super.processCompleted(event);
        List<WxMpTemplateMessage> list = new ArrayList<>();
        ProcessInstance processInstance = runtimeService.createProcessInstanceQuery().processInstanceId(event.getProcessInstanceId()).singleResult();
        String startUserId = processInstance.getStartUserId();
        SysUser sysUser = sysUserMapper.selectUserById(Convert.toLong(startUserId));
        //模板数据
        WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                .toUser(this.getMsgId(sysUser.getPhonenumber()))
                .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(Convert.toLong(processInstance.getBusinessKey()))));
        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", processInstance.getProcessDefinitionName()));
        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "申请审批通过"));
        templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,processInstance.getStartTime())));
        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", sysUser.getNickName()+"["+this.getMsgDepName(sysUser.getDeptId())+"]"));
        list.add(templateMessage);
        this.send(list,processInstance.getProcessDefinitionKey());
    }

    @Override
    protected void taskCreated(FlowableEngineEntityEvent event) {
        log.info("创建任务节点...{}",event.getProcessInstanceId());
        super.taskCreated(event);
        List<WxMpTemplateMessage> list = new ArrayList<>();
        TaskEntity taskEntity = (TaskEntity)event.getEntity();
        List<IdentityLink> idList = taskService.getIdentityLinksForTask(taskEntity.getId());
        if (CollectionUtils.isNotEmpty(idList)) {
            List<String> candidateUsers = new ArrayList<>();
            List<String> candidateGroups = new ArrayList<>();
            idList.forEach(identityLink -> {
                if (StringUtils.isNotBlank(identityLink.getUserId())) {
                    candidateUsers.add(identityLink.getUserId());
                }
                if (StringUtils.isNotBlank(identityLink.getGroupId())) {
                    candidateGroups.add(identityLink.getGroupId());
                }
            });
            log.info("查询任务节点...{}",String.join(",",candidateUsers),String.join(",",candidateGroups));
            if(StringUtils.isNotEmpty(candidateUsers) || StringUtils.isNotEmpty(candidateGroups)){
                ProcessInstance processInstance = runtimeService.createProcessInstanceQuery().processInstanceId(taskEntity.getProcessInstanceId()).singleResult();
                List<SysUser> sysUserList = flowBusinessKeyService.findFlowTaskUsers(processInstance.getBusinessKey(),candidateUsers,candidateGroups);
                if(StringUtils.isNotEmpty(sysUserList)){
                    String startUserId = processInstance.getStartUserId();
                    SysUser sysUser = sysUserMapper.selectUserById(Convert.toLong(startUserId));
                    for(SysUser taskUser:sysUserList){
                        //模板数据
                        WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                                .toUser(this.getMsgId(taskUser.getPhonenumber()))
                                .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(Convert.toLong(processInstance.getBusinessKey()))));
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", processInstance.getProcessDefinitionName()));
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", Objects.equals(taskEntity.getName(),"提交申请")?"申请审批驳回":"待"+taskEntity.getName()));
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,processInstance.getStartTime())));
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", sysUser.getNickName()+"["+this.getMsgDepName(sysUser.getDeptId())+"]"));
                        list.add(templateMessage);
                    }
                    this.send(list,processInstance.getProcessDefinitionKey());
                }
            }
        }
    }

    @Override
    protected void taskCompleted(FlowableEngineEntityEvent event) {
        log.info("任务节点审批通过...{}",event.getProcessInstanceId());
        super.taskCompleted(event);
        List<WxMpTemplateMessage> list = new ArrayList<>();
        TaskEntity taskEntity = (TaskEntity)event.getEntity();
        Task task = taskService.createTaskQuery().taskId(taskEntity.getId()).singleResult();
        // 查询任务...
        ProcessInstance processInstance = runtimeService.createProcessInstanceQuery().processInstanceId(taskEntity.getProcessInstanceId()).singleResult();
        String startUserId = processInstance.getStartUserId();
        SysUser sysUser = sysUserMapper.selectUserById(Convert.toLong(startUserId));
        if (Objects.nonNull(task)) {
            // Step 2. 获取当前流程所有流程变量(网关节点时需要校验表达式)
            Map<String, Object> variables = taskEntity.getVariables();
            UserTask nextUserTask = FindNextNodeUtil.getNextUserTasks(repositoryService, task, variables).get(0);
            List<SysUser> sysUserList = flowBusinessKeyService.findFlowTaskUsers(processInstance.getBusinessKey(),nextUserTask.getCandidateUsers(),nextUserTask.getCandidateGroups());
            if(StringUtils.isNotEmpty(sysUserList)){
                for(SysUser taskUser:sysUserList){
                    //模板数据
                    WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                            .toUser(this.getMsgId(taskUser.getPhonenumber()))
                            .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(Convert.toLong(processInstance.getBusinessKey()))));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", processInstance.getProcessDefinitionName()));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+nextUserTask.getName()));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,processInstance.getStartTime())));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", sysUser.getNickName()+"["+this.getMsgDepName(sysUser.getDeptId())+"]"));
                    list.add(templateMessage);
                }
                this.send(list,processInstance.getProcessDefinitionKey());
            }
        }
    }

    /**
     * 查询单位名称
     * @param depId
     * @return
     */
    private String getMsgDepName(Long depId){
        String name = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_DNAME +depId));
        if(StringUtils.isNotEmpty(name)){
            return name;
        }else{
            SysDept sysDept = sysDeptMapper.selectDeptById(depId);
            //项目名称截取&&超过20字符微信限制并抛出异常
            String depName = sysDept.getDeptName();
            if(depName.length()>13){
                depName = sysDept.getDeptName().substring(0,13);
            }
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_DNAME +depId,depName,30, TimeUnit.MINUTES);
            return depName;
        }
    }

    /**
     * 查询项目名称
     * @param proId
     * @return
     */
    private String getMsgProName(Long proId){
        String name = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_PNAME +proId));
        if(StringUtils.isNotEmpty(name)){
            return name;
        }else{
            Map<String, Object> proMap = flowBusinessKeyService.selectSurProjectById(proId);
            //项目名称截取&&超过20字符微信限制并抛出异常
            String proName = Convert.toStr(proMap.get("projectName"));
            if(proName.length()>20){
                proName = proName.substring(0,20);
            }
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_PNAME +proId,proName,30, TimeUnit.MINUTES);
            return proName;
        }
    }

    /**
     * 查询微信用户列表
     * @param userName
     * @return
     */
    private String getMsgId(String userName){
        String openIds = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName));
        if(StringUtils.isNotEmpty(openIds)){
            return openIds;
        }else{
            List<SysUserOpenid> list = sysUserOpenidMapper.findSysUserOpenidsByUser(userName);
            List<String> strs = list.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
            openIds = String.join(",",strs);
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName,openIds,30, TimeUnit.MINUTES);
            return openIds;
        }
    }

    /**
     * 模板消息开关
     */
    private boolean wxSwitch = true;

    /**
     * 推送模板消息
     * @param lsit
     */
    private void send(List<WxMpTemplateMessage> lsit, String messageType){
        try {
            if(wxSwitch && StringUtils.isNotEmpty(lsit)){
                for(WxMpTemplateMessage message:lsit){
                    if(StringUtils.isNotEmpty(message.getToUser())){
                        String[] toUsers = message.getToUser().split(",");
                        for(String toUser:toUsers){
                            //判断短时间内是否已发送相同类型的消息
                            String key = CacheConstants.WX_MPMESSAGE_KEY +toUser+"-"+messageType;
                            if(Convert.toBool(redisCache.getCacheObject(key),true)){
                                //多个登录账号时批量发送
                                message.setToUser(toUser);
                                wxMpService.getTemplateMsgService().sendTemplateMsg(message);
                                //5分钟内不推送相同类型的消息
                                redisCache.setCacheObject(key,false,5, TimeUnit.MINUTES);
                            }
                        }
                    }
                }
            }
        }catch (Exception e){
            log.info("出错了...{}",e.getMessage());
        }
    }

}


