package com.ruoyi.quartz.service.impl;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.quartz.mapper.TaskMapper;
import com.ruoyi.quartz.service.ITaskService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * 定时任务ServiceImpl
 *
 * @author JiangYuQi
 */
@Service
public class ITaskServiceImpl implements ITaskService {

    @Autowired
    private TaskMapper taskMapper;

    /**
     * 查询超时3天未办理的任务
     */
    public List<Map<String, Object>> findDaysAwaitFlowTask(){
        return taskMapper.findDaysAwaitFlowTask();
    }

    /**
     * 根据条件查询流程用户
     * @param businessKey 流程归属表单
     * @param candidateUsers 办理用户列表
     * @param candidateGroups 办理角色列表
     * @return
     */
    @Override
    public List<SysUser> findFlowTaskUsers(String businessKey, List<String> candidateUsers, List<String> candidateGroups){
        if(StringUtils.isNotEmpty(candidateGroups) && candidateGroups.contains("47")){
            return taskMapper.findFlowTaskDeptUsers(businessKey,candidateUsers,candidateGroups);
        }else{
            return taskMapper.findFlowTaskUsers(businessKey,candidateUsers,candidateGroups);
        }
    }

    /**
     * 查询用户绑定小程序openId列表
     *
     * @param userName 用户登录名
     * @return 用户绑定小程序openId集合
     */
    public List<Map<String, Object>> findSysUserOpenidsByUser(String userName) {
        return taskMapper.findSysUserOpenidsByUser(userName);
    }

    /**
     * 查询用户绑定小程序openId列表[项目甲代]
     *
     * @param proId 项目信息
     * @return 用户绑定小程序openId集合
     */
    public List<Map<String, Object>> findMsgProMagUsers(Long proId) {
        return taskMapper.findMsgProMagUsers(proId);
    }
}
