package com.ruoyi.quartz.task;

import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.TemplateMessageEnum;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.quartz.service.ITaskService;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateData;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * 工作流任务超时提醒定时任务
 *
 * @author JiangYuQi
 */
@Slf4j
@Component("flowTaskExpiredTask")
public class FlowTaskExpiredTask {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private WxMpService wxMpService;

    @Autowired
    private ITaskService taskService;

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyApplyExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
        boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
        if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::工程审批超时提醒定时任务...{}");
            List<Map<String, Object>> list = taskService.findDaysAwaitFlowTask();
            for(Map<String, Object> dataMap:list){
                List<String> candidateUsers = new ArrayList<>();
                List<String> candidateGroups = new ArrayList<>();
                if(StringUtils.isNotNull(dataMap.get("ASSIGNEE_"))){
                    candidateUsers.add(Convert.toStr(dataMap.get("ASSIGNEE_")));
                }
                if(StringUtils.isNotNull(dataMap.get("USER_ID_"))){
                    candidateUsers.add(Convert.toStr(dataMap.get("USER_ID_")));
                }
                if(StringUtils.isNotNull(dataMap.get("GROUP_ID_"))){
                    candidateGroups.add(Convert.toStr(dataMap.get("GROUP_ID_")));
                }
                String businessKey = Convert.toStr(dataMap.get("businessKey"));
                String businessKeyName = Convert.toStr(dataMap.get("businessKeyName"));
                List<SysUser> sysUserList = taskService.findFlowTaskUsers(businessKey,candidateUsers,candidateGroups);
                if(StringUtils.isNotEmpty(sysUserList)){
                    for(SysUser taskUser:sysUserList){
                        //模板数据
                        WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                                .toUser(this.getMsgId(taskUser.getPhonenumber()))
                                .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
//                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", businessKeyName));
//                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", processInstance.getProcessDefinitionName()));
//                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", Objects.equals(taskEntity.getName(),"提交申请")?"申请审批驳回":"待"+taskEntity.getName()));
//                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,processInstance.getStartTime())));
//                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", sysUser.getNickName()+"["+this.getMsgDepName(sysUser.getDeptId())+"]"));
//                        list.add(templateMessage);
                    }
                    //this.send(list,processInstance.getProcessDefinitionKey());
                }
            }
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
            log.info("释放锁...{}", key);
            redisLock.unlock(key);
        }
        }else{
            log.info("尝试劫持锁失败...{}", key);
        }*/
    }

    /**
     * 查询微信用户列表
     * @param userName
     * @return
     */
    private String getMsgId(String userName){
        String openIds = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName));
        if(StringUtils.isNotEmpty(openIds)){
            return openIds;
        }else{
            List<Map<String, Object>> list = taskService.findSysUserOpenidsByUser(userName);
            List<String> strs = list.stream().map(Map -> Map.get("msgOpenId").toString()).collect(Collectors.toList());
            openIds = String.join(",",strs);
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName,openIds,30, TimeUnit.MINUTES);
            return openIds;
        }
    }

    /**
     * 模板消息开关
     */
    private boolean wxSwitch = true;

    /**
     * 推送模板消息
     * @param lsit
     */
    private void send(List<WxMpTemplateMessage> lsit, String messageType){
        try {
            if(wxSwitch && StringUtils.isNotEmpty(lsit)){
                for(WxMpTemplateMessage message:lsit){
                    if(StringUtils.isNotEmpty(message.getToUser())){
                        String[] toUsers = message.getToUser().split(",");
                        for(String toUser:toUsers){
                            //判断短时间内是否已发送相同类型的消息
                            String key = CacheConstants.WX_MPMESSAGE_KEY +toUser+"-"+messageType;
                            if(Convert.toBool(redisCache.getCacheObject(key),true)){
                                //多个登录账号时批量发送
                                message.setToUser(toUser);
                                wxMpService.getTemplateMsgService().sendTemplateMsg(message);
                                //5分钟内不推送相同类型的消息
                                redisCache.setCacheObject(key,false,5, TimeUnit.MINUTES);
                            }
                        }
                    }
                }
            }
        }catch (Exception e){
            log.info("出错了...{}",e.getMessage());
        }
    }
}
