package com.yanzhu.jh.bigscreen.web.controller;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.PageDomain;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.page.TableSupport;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.sign.Md5Utils;
import com.yanzhu.jh.work.domain.WorkTrain;
import com.yanzhu.jh.work.service.IWorkTrainService;
import liquibase.util.MD5Util;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * 培训演训Conller
 */
@RestController
@RequestMapping("/bgscreen/workTrain")
public class BgWorkTrainController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    IWorkTrainService workTrainService;

    /**
     * 根据类型查询培训演训
     * @param trainType
     * @return
     */
    @GetMapping("/getWorkTrainList")
    public TableDataInfo getWorkTrainList(String trainType,String deptId,String projectId,String proType){
        String key="bgscreen_workTrain_getWorkTrainList_"+trainType+"-"+deptId+"-"+projectId+"-"+proType;
        List<Object> objs=redisCache.getCacheObject(key);
        if(objs!=null){
            return getDataTable(objs);
        }
        WorkTrain workTrain = new WorkTrain();
        workTrain.setTrainType(trainType);
        if(deptId!=null && !"0".equals(deptId)){
            workTrain.setNowDept(deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                workTrain.setPrjIds(getProjectIds());
            }
        }
        if(projectId!=null && !"0".equals(projectId)){
            workTrain.setProjectId(Convert.toLong(projectId));
        }
        if(proType!=null && !"0".equals(proType)){
            workTrain.setProType(projectId);
        }
        List<WorkTrain> list = workTrainService.selectBgscreenWorkTrainListv2(workTrain);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return getDataTable(list);
    }

    /**
     * 大屏教训培训，应急演练图标数据查询
     * @return
     */
    @GetMapping("/getGroupByDataType")
    public AjaxResult getGroupByDataType(String deptId, String projectId){
        WorkTrain workTrain = new WorkTrain();
        if(deptId!=null && !"0".equals(deptId)){
            workTrain.setNowDept(deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                workTrain.setPrjIds(getProjectIds());
            }
        }
        String key="bgscreen_workTrain_getGroupByDataType_"+deptId+"-"+projectId+"-"+workTrain.getProType()+Md5Utils.hash(workTrain.getPrjIds());
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }
        if(projectId!=null && !"0".equals(projectId)){
            workTrain.setProjectId(Convert.toLong(projectId));
        }
        List<WorkTrain> list = workTrainService.getGroupByDataType(workTrain);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return AjaxResult.success(list);
    }

    /**
     * deptId: this.deptId,
     * projectId: this.projectId,
     * trainType: this.trainType,
     * dataType: this.nav
     * @param where
     * @return
     */
    @PostMapping("/queryWorkTrainList")
    public TableDataInfo queryWorkTrainList(@RequestBody WorkTrain where){
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        Long deptId= where.getDeptId();
        if(deptId!=null && deptId>0){
            where.setNowDept(""+deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                where.setPrjIds(getProjectIds());
            }
        }
        String key="bgscreen_workTrain_queryWorkTrainList_"+pageNum+"-"+pageSize+"-"+where.getDeptId()+"-"+where.getProjectId()+"-"+where.getTrainType()+"-"+where.getDataType()+"-"+where.getProType()+Md5Utils.hash(where.getPrjIds());
        List<Object> objs=redisCache.getCacheObject(key);
        if(objs!=null){
            return getDataTable(objs);
        }

        if(StringUtils.isEmpty(where.getProType()) ||  "0".equals(where.getProType())){
            where.setProType(null);
        }
        startPage();
        List<WorkTrain> list=workTrainService.queryWorkTrainList(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return getDataTable(list);
    }

}
