package com.yanzhu.jh.bigscreen.web.controller;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.PageDomain;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.page.TableSupport;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.sign.Md5Utils;
import com.yanzhu.jh.project.domain.SurProjectChecking;
import com.yanzhu.jh.project.service.ISurProjectCheckingService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * 项目验收Conller
 */
@RestController
@RequestMapping("/bgscreen/projectChecking")
public class ProjectCheckingController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private ISurProjectCheckingService surProjectCheckingService;

    /**
     * 根据条件查询项目举牌验收列表
     * @param deptId
     * @param projectId
     * @return
     */
    @GetMapping("/getProjectCheckingList")
    public TableDataInfo getProjectCheckingList(String deptId, String projectId){
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        SurProjectChecking surProjectChecking = new SurProjectChecking();
        if(deptId!=null && !"0".equals(deptId)){
            surProjectChecking.setProjectDeptId(deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                surProjectChecking.setPrjIds(getProjectIds());
            }
        }
        String key="bgscreen_projectChecking_getProjectCheckingList_"+pageNum+"-"+pageSize+"-"+"_"+surProjectChecking.getProjectDeptId()+deptId+"_"+projectId+"_"+surProjectChecking.getProType()+ Md5Utils.hash(surProjectChecking.getPrjIds());
        List<Object> objs=redisCache.getCacheObject(key);
        if(objs!=null){
            return getDataTable(objs);
        }
        if(projectId!=null && !"0".equals(projectId)){
            surProjectChecking.setProjectId(Convert.toLong(projectId));
        }
        List<SurProjectChecking> list = surProjectCheckingService.selectBgscreenProjectCheckingList(surProjectChecking);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return getDataTable(list);
    }

    /**
     * 根据条件查询项目举牌验收统计
     * @param deptId
     * @param projectId
     * @return
     */
    @GetMapping("/getProjectCheckingView")
    public AjaxResult getProjectCheckingView(String deptId, String projectId){
        SurProjectChecking surProjectChecking = new SurProjectChecking();
        if(deptId!=null && !"0".equals(deptId)){
            surProjectChecking.setProjectDeptId(deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                surProjectChecking.setPrjIds(getProjectIds());
            }
        }
        String key="bgscreen_projectChecking_getProjectCheckingView_"+deptId+"_"+surProjectChecking.getProjectDeptId()+"_"+projectId+"_"+surProjectChecking.getProType()+Md5Utils.hash(surProjectChecking.getPrjIds());
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }

        if(projectId!=null && !"0".equals(projectId)){
            surProjectChecking.setProjectId(Convert.toLong(projectId));
        }

        Map<String, Object> data = surProjectCheckingService.selectBgscreenProjectCheckingView(surProjectChecking);
        redisCache.setCacheObject(key, data, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(data);
    }

    /**
     * 根据验收类型2级分组查询，用于大屏质量管理-举牌验收图表
     * @param deptId
     * @param projectId
     * @return
     */
    @GetMapping("/getProjectCheckingGroupFoChart")
    public AjaxResult getProjectCheckingGroupFoChart(String deptId, String projectId){
        SurProjectChecking surProjectChecking = new SurProjectChecking();
        if(deptId!=null && !"0".equals(deptId)){
            surProjectChecking.setProjectDeptId(deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                surProjectChecking.setPrjIds(getProjectIds());
            }
        }
        String key="bgscreen_projectChecking_getProjectCheckingGroupFoChart_"+deptId+"_"+surProjectChecking.getProjectDeptId()+"_"+projectId+"_"+surProjectChecking.getProType()+Md5Utils.hash(surProjectChecking.getPrjIds());
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }

        if(projectId!=null && !"0".equals(projectId)){
            surProjectChecking.setProjectId(Convert.toLong(projectId));
        }

        List<SurProjectChecking> list = surProjectCheckingService.getProjectCheckingGroupFoChart(surProjectChecking);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    /**
     * 根据验收类型2级分组查询，用于大屏质量管理-举牌验收分组查询
     * @param deptId
     * @param projectId
     * @return
     */
    @GetMapping("/groupCheckingByProjectId")
    public AjaxResult groupCheckingByProjectId(String lvl,String deptId, String projectId){
        SurProjectChecking surProjectChecking = new SurProjectChecking();
        surProjectChecking.setDataTypeLvl2(lvl);
        if(deptId!=null && !"0".equals(deptId)){
            surProjectChecking.setProjectDeptId(deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                surProjectChecking.setPrjIds(getProjectIds());
            }
        }
        String key="bgscreen_projectChecking_groupCheckingByProjectId_"+lvl+"-"+deptId+"_"+surProjectChecking.getProjectDeptId()+"_"+projectId+"_"+surProjectChecking.getProType()+Md5Utils.hash(surProjectChecking.getPrjIds());
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }

        if(projectId!=null && !"0".equals(projectId)){
            surProjectChecking.setProjectId(Convert.toLong(projectId));
        }

        List<SurProjectChecking> list = surProjectCheckingService.groupCheckingByProjectId(surProjectChecking);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    /**
     * 查询项目举牌验收列表
     * @param where
     * @return
     */
    @PostMapping("/queryProjectCheckingList")
    public TableDataInfo queryProjectCheckingList(@RequestBody SurProjectChecking where){
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        Long deptId=where.getDeptId();
        Long projectId=where.getProjectId();
        if(deptId!=null && deptId.equals(0)){
            where.setProjectDeptId(""+deptId);
            where.setDeptId(null);
        }else{
            if (SecurityUtils.isUserB()) {
                where.setPrjIds(getProjectIds());
            }
        }
        String key="bgscreen_projectChecking_groupCheckingByProjectId_"+pageNum+"-"+pageSize+"_"+where.getDeptId()+"_"+where.getProjectDeptId()+"_"+where.getProjectId()+"_"+where.getProType()+Md5Utils.hash(where.getPrjIds());
        List<Object> objs=redisCache.getCacheObject(key);
        if(objs!=null){
            return getDataTable(objs);
        }
        if(projectId!=null && projectId.equals(0)){
            where.setProjectId(Convert.toLong(projectId));
        }
        startPage();
        List<SurProjectChecking> list = surProjectCheckingService.selectBgscreenProjectCheckingListByPage(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return getDataTable(list);
    }
}
