package com.yanzhu.jh.bigscreen.web.controller;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.sign.Md5Utils;
import com.yanzhu.jh.project.domain.SurProject;
import com.yanzhu.jh.project.domain.SurProjectUserinfo;
import com.yanzhu.jh.project.service.ISurProjectService;
import com.yanzhu.jh.project.domain.SurProjectBuildNodeData;
import com.yanzhu.jh.project.service.ISurProjectBuildNodeDataService;
import com.yanzhu.jh.project.service.ISurProjectUserinfoService;
import org.aspectj.weaver.loadtime.Aj;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;

@RestController
@RequestMapping("/bgscreen/project")
public class ProjectController  extends BaseController {

    @Autowired
    private ISurProjectService isurProjectService;

    @Autowired
    private ISurProjectBuildNodeDataService surProjectBuildNodeDataService;

    @Autowired
    private ISurProjectUserinfoService surProjectUserinfoService;

    @Autowired
    private RedisCache redisCache;

    @GetMapping("/findProjectByDept")
    public AjaxResult findProjectByDept(Long deptId){
        SurProject surProject=new SurProject();
        if(deptId==-1){
            long roleId= SecurityUtils.getRoleId();
            if(5==roleId||6==roleId||7==roleId){
                surProject.setDeptId(getDeptId());
            }else{
                surProject.setId(SecurityUtils.getUserId());
            }
            return success(isurProjectService.selectSurProjectListByBuser(surProject));
        }

        if(deptId!=null &&  deptId.longValue()>0){
            surProject.setDeptId(deptId);
        }
        List<SurProject> list=isurProjectService.selectSurProjectList(surProject);
        for (SurProject p :list){
            //DateTime dt1= DateUtil.parse(p.getScheduledStartTime());
            //DateTime dt2=DateUtil.parse(p.getPlannedCompletionTime());
            //long days= DateUtil.between(dt1,dt2, DateUnit.DAY);
            //p.setProjectTimeLimit(days);
        }
        return success(list);
    }

    @GetMapping("/getProjectBuildNode")
    public AjaxResult getProjectBuildNode(Long projectId){
        SurProjectBuildNodeData nodeData=new SurProjectBuildNodeData();
        nodeData.setProjectId(projectId);
        List list=surProjectBuildNodeDataService.selectSurProjectBuildNodeDataList(nodeData);
        if(list.size()>0){
            return success(list);
        }
        surProjectBuildNodeDataService.addProjectNodes(projectId);
        list=surProjectBuildNodeDataService.selectSurProjectBuildNodeDataList(nodeData);
        return success(list);
    }

    /**
     * 获取进度显示的项目
     * @return
     */
    @GetMapping("/getProgressProjects")
    public AjaxResult getProgressProjects(long deptId){
        SurProject where=new SurProject();
        if(deptId<=0){
            if (SecurityUtils.isUserB()) {
                where.setPrjIds(getProjectIds());
            }
        }else{
            where.setDeptId(deptId);
        }
        String key="bgscreen_prj_getProgressProjects_"+deptId+"_"+ Md5Utils.hash(where.getPrjIds());
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }
        List<SurProject> list= isurProjectService.selectProgressProjects(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    @GetMapping("/groupByProjectCategory")
    public AjaxResult groupByProjectCategory(long deptId){
        SurProject where=new SurProject();
        if(deptId<=0){
            if (SecurityUtils.isUserB()) {
                where.setPrjIds(getProjectIds());
            }
        }else{
            where.setDeptId(deptId);
        }
        String key="bgscreen_prj_groupByProjectCategory_"+deptId+"_"+where.getProType()+"_"+ Md5Utils.hash(where.getPrjIds());
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }
        List<SurProject> list= isurProjectService.groupByProjectCategory(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    @PostMapping("/groupByCategory")
    public AjaxResult groupByCategory(@RequestBody SurProject surProject){
        String key="bgscreen_prj_groupByProjectCategory_"+surProject.getId()+"_"+surProject.getDeptId()+surProject.getProType();
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }
        List<SurProject> list=isurProjectService.groupByCategory(surProject);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    @PostMapping("/groupByLevel")
    public AjaxResult groupByLevel(@RequestBody SurProject surProject){
        String key="bgscreen_prj_groupByLevel_"+surProject.getId()+"_"+surProject.getDeptId()+surProject.getProType();
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }
        List<SurProject> list=isurProjectService.groupByLevel(surProject);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    @GetMapping("/getProjectUser")
    public AjaxResult getProjectUser(Long projectId){
        String key="bgscreen_prj_getProjectUser_"+projectId;
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }
        SurProjectUserinfo where=new SurProjectUserinfo();
        where.setProjectId(projectId);
        List<SurProjectUserinfo> list = surProjectUserinfoService.selectSurProjectUserinfoList(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }
    
    
}
