package com.yanzhu.jh.project.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.SurProjectWorkingCommittee;
import com.yanzhu.jh.project.service.ISurProjectWorkingCommitteeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工委会管理Controller
 * 
 * @author ruoyi
 * @date 2024-04-06
 */
@RestController
@RequestMapping("/project/projectCommittee")
public class SurProjectWorkingCommitteeController extends BaseController
{
    @Autowired
    private ISurProjectWorkingCommitteeService surProjectWorkingCommitteeService;

    /**
     * 查询工委会管理列表
     */
    @PreAuthorize("@ss.hasPermi('project:projectCommittee:list')")
    @GetMapping("/list")
    public TableDataInfo list(SurProjectWorkingCommittee surProjectWorkingCommittee)
    {
        startPage();
        List<SurProjectWorkingCommittee> list = surProjectWorkingCommitteeService.selectSurProjectWorkingCommitteeList(surProjectWorkingCommittee);
        return getDataTable(list);
    }

    /**
     * 导出工委会管理列表
     */
    @PreAuthorize("@ss.hasPermi('project:projectCommittee:export')")
    @Log(title = "工委会管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurProjectWorkingCommittee surProjectWorkingCommittee)
    {
        List<SurProjectWorkingCommittee> list = surProjectWorkingCommitteeService.selectSurProjectWorkingCommitteeList(surProjectWorkingCommittee);
        ExcelUtil<SurProjectWorkingCommittee> util = new ExcelUtil<SurProjectWorkingCommittee>(SurProjectWorkingCommittee.class);
        util.exportExcel(response, list, "工委会管理数据");
    }

    /**
     * 获取工委会管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:projectCommittee:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectWorkingCommitteeService.selectSurProjectWorkingCommitteeById(id));
    }

    /**
     * 新增工委会管理
     */
    @PreAuthorize("@ss.hasPermi('project:projectCommittee:add')")
    @Log(title = "工委会管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SurProjectWorkingCommittee surProjectWorkingCommittee)
    {
        return toAjax(surProjectWorkingCommitteeService.insertSurProjectWorkingCommittee(surProjectWorkingCommittee));
    }

    /**
     * 修改工委会管理
     */
    @PreAuthorize("@ss.hasPermi('project:projectCommittee:edit')")
    @Log(title = "工委会管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectWorkingCommittee surProjectWorkingCommittee)
    {
        return toAjax(surProjectWorkingCommitteeService.updateSurProjectWorkingCommittee(surProjectWorkingCommittee));
    }

    /**
     * 删除工委会管理
     */
    @PreAuthorize("@ss.hasPermi('project:projectCommittee:remove')")
    @Log(title = "工委会管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectWorkingCommitteeService.deleteSurProjectWorkingCommitteeByIds(ids));
    }
}
