package com.yanzhu.jh.project.mapper;

import java.util.List;
import java.util.Map;

import com.yanzhu.jh.project.domain.SurProjectInsurance;

/**
 * 项目保险Mapper接口
 * 
 * @author JiangYuQi
 * @date 2023-08-16
 */
public interface SurProjectInsuranceMapper 
{
    /**
     * 查询项目保险
     * 
     * @param id 项目保险主键
     * @return 项目保险
     */
    public SurProjectInsurance selectSurProjectInsuranceById(Long id);

    /**
     * 查询项目保险列表
     * 
     * @param surProjectInsurance 项目保险
     * @return 项目保险集合
     */
    public List<SurProjectInsurance> selectSurProjectInsuranceList(SurProjectInsurance surProjectInsurance);

    /**
     * 查询大屏保险统计列表
     *
     * @param surProjectInsurance 项目保险
     * @return map集合
     */
    public List<Map<String,Object>> selectBgscreenInsuranceList(SurProjectInsurance surProjectInsurance);

    /**
     * 查询项目保险列表
     *
     * @param surProjectInsurance 项目保险
     * @return 项目保险集合
     */
    public List<SurProjectInsurance> selectSurProjectInsuranceListv2(SurProjectInsurance surProjectInsurance);

    /**
     * 新增项目保险
     * 
     * @param surProjectInsurance 项目保险
     * @return 结果
     */
    public int insertSurProjectInsurance(SurProjectInsurance surProjectInsurance);

    /**
     * 修改项目保险
     * 
     * @param surProjectInsurance 项目保险
     * @return 结果
     */
    public int updateSurProjectInsurance(SurProjectInsurance surProjectInsurance);

    /**
     * 删除项目保险
     * 
     * @param id 项目保险主键
     * @return 结果
     */
    public int deleteSurProjectInsuranceById(Long id);

    /**
     * 批量删除项目保险
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSurProjectInsuranceByIds(Long[] ids);

    /**
     * 查询保险是否已办理
     *
     * @param surProjectInsurance 查询条件
     * @return 结果
     */
    public int findInsuranceByParams(SurProjectInsurance surProjectInsurance);

    /**
     * 按项目获取保险信息
     * @param projectId
     * @return
     */
    public List<SurProjectInsurance> selectProjectInsuranceListByProjectId(Long projectId);

    /**
     * 根据项目统计保险
     *
     * @param projectId 项目主键
     * @return 结果
     */
    public List<Map<String,Object>> findGroupCountByProjectId(Long projectId);
}
