package com.yanzhu.jh.video.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.video.domain.SurProjectPhotography;
import com.yanzhu.jh.video.service.ISurProjectPhotographyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 项目项目全景Controller
 * 
 * @author ruoyi
 * @date 2023-10-15
 */
@RestController
@RequestMapping("/video/prjphotography")
public class SurProjectPhotographyController extends BaseController
{
    @Autowired
    private ISurProjectPhotographyService surProjectPhotographyService;

    /**
     * 查询项目项目全景列表
     */
    @PreAuthorize("@ss.hasPermi('video:prjphotography:list')")
    @GetMapping("/list")
    public TableDataInfo list(SurProjectPhotography surProjectPhotography)
    {
        startPage();
        List<SurProjectPhotography> list = surProjectPhotographyService.selectSurProjectPhotographyList(surProjectPhotography);
        return getDataTable(list);
    }

    /**
     * 导出项目项目全景列表
     */
    @PreAuthorize("@ss.hasPermi('video:prjphotography:export')")
    @Log(title = "项目全景", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurProjectPhotography surProjectPhotography)
    {
        List<SurProjectPhotography> list = surProjectPhotographyService.selectSurProjectPhotographyList(surProjectPhotography);
        ExcelUtil<SurProjectPhotography> util = new ExcelUtil<SurProjectPhotography>(SurProjectPhotography.class);
        util.exportExcel(response, list, "项目全景数据");
    }

    /**
     * 获取项目项目全景详细信息
     */
    @PreAuthorize("@ss.hasPermi('video:prjphotography:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectPhotographyService.selectSurProjectPhotographyById(id));
    }

    /**
     * 新增项目项目全景
     */
    @PreAuthorize("@ss.hasPermi('video:prjphotography:add')")
    @Log(title = "项目项目全景", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SurProjectPhotography surProjectPhotography)
    {
        return toAjax(surProjectPhotographyService.insertSurProjectPhotography(surProjectPhotography));
    }

    /**
     * 修改项目项目全景
     */
    @PreAuthorize("@ss.hasPermi('video:prjphotography:edit')")
    @Log(title = "项目项目全景", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectPhotography surProjectPhotography)
    {
        return toAjax(surProjectPhotographyService.updateSurProjectPhotography(surProjectPhotography));
    }

    /**
     * 删除项目项目全景
     */
    @PreAuthorize("@ss.hasPermi('video:prjphotography:remove')")
    @Log(title = "项目项目全景", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectPhotographyService.deleteSurProjectPhotographyByIds(ids));
    }
}
