package com.yanzhu.jh.wxsetting.controller;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.api.WxConsts;
import me.chanjar.weixin.common.exception.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.result.WxMpOAuth2AccessToken;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.net.URLEncoder;

/**
 * 微信openId绑定
 *
 * @author JiangYuQi
 * @date 2023-08-24
 */
@Slf4j
@Controller
@RequestMapping("/wxAuth")
public class WxAuthController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private WxMpService wxMpService;

    @Anonymous
    @GetMapping("/auth")
    @ResponseBody
    public String auth(@RequestParam(value = "echostr", defaultValue = "没有获取到") String echostr) {
        return echostr;
    }

    @Anonymous
    @ResponseBody
    @GetMapping("/getWxAccessToken")
    public AjaxResult getWxAccessToken(){
        try {
            return success(wxMpService.getAccessToken());
        }catch (Exception e){
            return error(e.getMessage());
        }
    }

    @Anonymous
    @ResponseBody
    @GetMapping("/deleteTestCache")
    public AjaxResult deleteTestCache(){
        redisCache.deleteObject(CacheConstants.WX_MPMESSAGE_UNAME+"*");
        redisCache.deleteObject(CacheConstants.WX_MPMESSAGE_PNAME+"*");
        redisCache.deleteObject(CacheConstants.WX_MPMESSAGE_DNAME+"*");
        redisCache.deleteObject(CacheConstants.WX_MPMESSAGE_P_SUP+"*");
        redisCache.deleteObject(CacheConstants.WX_MPMESSAGE_P_MAG+"*");
        return success();
    }

    /**
     * @author ：tao
     * @param: ：
     * @return： 重定向到获取用户信息的类
     * 微信授权登录
     */
    @Anonymous
    @GetMapping("/authorize")
    public void authorize(@RequestParam(value = "returnUrl", defaultValue = "https://szgc.jhncidg.com/jhapi/") String returnUrl, HttpServletResponse response) throws Exception {
        log.info("【微信网页授权】进来了，参数={}", returnUrl);
        //1. 配置
        //2. 调用方法
        String url = RuoYiConfig.getProjectUrl() + "wxAuth/userInfo";
        /*
         * 相当于这种形式
         * URLEncoder.decode(returnUrl,"UTF-8"
         * https://open.weixin.qq.com/connect/oauth2/authorize?appid=APPID&redirect_uri=REDIRECT_URI&response_type=code&scope=SCOPE&state=STATE#wechat_redirect
         */
        String redirectUrl = wxMpService.oauth2buildAuthorizationUrl(url, WxConsts.OAUTH2_SCOPE_USER_INFO, URLEncoder.encode(returnUrl, "utf-8"));
        log.info("【微信网页授权】获取code,result={}", redirectUrl);
        response.sendRedirect(redirectUrl);
    }

    /**
     * @author ：tao
     * @param: ：
     * @return： 重定向
     * 获取用户信息类，最后重定向到指定url
     */
    @Anonymous
    @GetMapping("/userInfo")
    public void userInfo(@RequestParam("code") String code,
                           @RequestParam("state") String returnUrl,HttpServletResponse response) throws Exception {
        /*当用户同意授权后，会回调所设置的url并把authorization code传过来，
        然后用这个code获得access token，其中也包含用户的openid等信息*/
        WxMpOAuth2AccessToken wxMpOAuth2AccessToken = new WxMpOAuth2AccessToken();
        try {
            //获取access token
            wxMpOAuth2AccessToken = wxMpService.oauth2getAccessToken(code);
            log.info("【AccessToken：】{}", wxMpOAuth2AccessToken.getAccessToken());
        } catch (WxErrorException e) {
            log.error("【微信网页授权】{}", e);
        }

        // 拿到openid
        String openId = wxMpOAuth2AccessToken.getOpenId();
        log.info("【openid：】{}", openId);
        log.info("【我是前端要回调的地址：】{}", returnUrl + "&openid=" + openId);
        // 顺便获取一下用户信息
        WxMpUser wxMpUser = wxMpService.oauth2getUserInfo(wxMpOAuth2AccessToken, "zh_CN");
        log.info("【用户信息：】{}", wxMpUser.toString());

        //注意拼接参数，第一个参数需要加问号，之后参数使用&拼接的问题
        //return "redirect:" + returnUrl + "/#/?openid=" + openId;
        response.sendRedirect(returnUrl + "&openid=" + openId);
    }

}
